@@ -83,64 +83,69 @@ void FixedJointReductionEquivalence(const std::string &_file)
   }
 
   std::map<std::string, double> linkMasses;
-  std::map<std::string, sdf::Pose> linkPoses;
-  std::map<std::string, sdf::Vector3> mapIxxIyyIzz;
-  std::map<std::string, sdf::Vector3> mapIxyIxzIyz;
+  std::map<std::string, ignition::math::Pose3d> linkPoses;
+  std::map<std::string, ignition::math::Vector3d> mapIxxIyyIzz;
+  std::map<std::string, ignition::math::Vector3d> mapIxyIxzIyz;
 
   {
     std::string linkName = "link0";
     linkMasses[linkName] = 1000;
-    linkPoses[linkName] = sdf::Pose(0, 0, -0.5, 0, -0, 0);
-    mapIxxIyyIzz[linkName] = sdf::Vector3(1, 1, 1);
-    mapIxyIxzIyz[linkName] = sdf::Vector3(0, 0, 0);
+    linkPoses[linkName] = ignition::math::Pose3d(0, 0, -0.5, 0, -0, 0);
+    mapIxxIyyIzz[linkName] = ignition::math::Vector3d(1, 1, 1);
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d(0, 0, 0);
   }
 
   {
     std::string linkName = "link1";
     linkMasses[linkName] = 100;
-    linkPoses[linkName] = sdf::Pose(0, -1.5, 0, -2.14159, 0.141593, 0.858407);
-    mapIxxIyyIzz[linkName] = sdf::Vector3(2, 3, 4);
-    mapIxyIxzIyz[linkName] = sdf::Vector3(0, 0, 0);
+    linkPoses[linkName] =
+      ignition::math::Pose3d(0, -1.5, 0, -2.14159, 0.141593, 0.858407);
+    mapIxxIyyIzz[linkName] = ignition::math::Vector3d(2, 3, 4);
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d(0, 0, 0);
   }
 
   {
     std::string linkName = "link2";
     linkMasses[linkName] = 200;
-    linkPoses[linkName] = sdf::Pose(0.2, 0.4, 1, -1.14159, -0.141593, 1.5708);
-    mapIxxIyyIzz[linkName] = sdf::Vector3(5, 6, 7);
-    mapIxyIxzIyz[linkName] = sdf::Vector3(0, 0, 0);
+    linkPoses[linkName] =
+      ignition::math::Pose3d(0.2, 0.4, 1, -1.14159, -0.141593, 1.5708);
+    mapIxxIyyIzz[linkName] = ignition::math::Vector3d(5, 6, 7);
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d(0, 0, 0);
   }
 
   {
     std::string linkName = "link3";
     linkMasses[linkName] = 400;
     linkPoses[linkName] =
-      sdf::Pose(0.1, 0.2, 0.3, -1.14159, 0.141593, 0.858407);
-    mapIxxIyyIzz[linkName] = sdf::Vector3(8, 9, 10);
-    mapIxyIxzIyz[linkName] = sdf::Vector3(0, 0, 0);
+      ignition::math::Pose3d(0.1, 0.2, 0.3, -1.14159, 0.141593, 0.858407);
+    mapIxxIyyIzz[linkName] = ignition::math::Vector3d(8, 9, 10);
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d(0, 0, 0);
   }
 
   {
     std::string linkName = "link1a";
     linkMasses[linkName] = 700;
-    linkPoses[linkName] =
-      sdf::Pose(1.6, -2.72857, -0.342857, -2.14159, 0.141593, 0.858407);
-    mapIxxIyyIzz[linkName] = sdf::Vector3(576.477, 527.681, 420.127);
-    mapIxyIxzIyz[linkName] = sdf::Vector3(-65.6808, 134.562, 264.781);
+    linkPoses[linkName] = ignition::math::Pose3d(
+      1.6, -2.72857, -0.342857, -2.14159, 0.141593, 0.858407);
+    mapIxxIyyIzz[linkName] =
+      ignition::math::Vector3d(576.477, 527.681, 420.127);
+    mapIxyIxzIyz[linkName] =
+      ignition::math::Vector3d(-65.6808, 134.562, 264.781);
   }
 
   // Count collisions and visuals
   unsigned int countVisuals = 0;
   unsigned int countCollisions = 0;
 
-  sdf::ElementPtr model = robot->root->GetElement("model");
+  sdf::ElementPtr model = robot->Root()->GetElement("model");
   for (sdf::ElementPtr link = model->GetElement("link"); link;
        link = link->GetNextElement("link"))
   {
     std::string linkName = link->Get<std::string>("name");
     sdf::ElementPtr inertial = link->GetElement("inertial");
     double linkMass = inertial->Get<double>("mass");
-    sdf::Pose linkPose = inertial->Get<sdf::Pose>("pose");
+    ignition::math::Pose3d linkPose =
+      inertial->Get<ignition::math::Pose3d>("pose");
     sdf::ElementPtr inertia = inertial->GetElement("inertia");
     double ixx = inertia->Get<double>("ixx");
     double iyy = inertia->Get<double>("iyy");
@@ -162,12 +167,12 @@ void FixedJointReductionEquivalence(const std::string &_file)
 
     EXPECT_NEAR(linkMass, linkMasses[linkName], gc_tolerance);
     EXPECT_EQ(linkPose, linkPoses[linkName]);
-    EXPECT_NEAR(ixx, mapIxxIyyIzz[linkName].x, gc_tolerance);
-    EXPECT_NEAR(iyy, mapIxxIyyIzz[linkName].y, gc_tolerance);
-    EXPECT_NEAR(izz, mapIxxIyyIzz[linkName].z, gc_tolerance);
-    EXPECT_NEAR(ixy, mapIxyIxzIyz[linkName].x, gc_tolerance);
-    EXPECT_NEAR(ixz, mapIxyIxzIyz[linkName].y, gc_tolerance);
-    EXPECT_NEAR(iyz, mapIxyIxzIyz[linkName].z, gc_tolerance);
+    EXPECT_NEAR(ixx, mapIxxIyyIzz[linkName].X(), gc_tolerance);
+    EXPECT_NEAR(iyy, mapIxxIyyIzz[linkName].Y(), gc_tolerance);
+    EXPECT_NEAR(izz, mapIxxIyyIzz[linkName].Z(), gc_tolerance);
+    EXPECT_NEAR(ixy, mapIxyIxzIyz[linkName].X(), gc_tolerance);
+    EXPECT_NEAR(ixz, mapIxyIxzIyz[linkName].Y(), gc_tolerance);
+    EXPECT_NEAR(iyz, mapIxyIxzIyz[linkName].Z(), gc_tolerance);
 
     if (link->HasElement("collision"))
     {
@@ -225,67 +230,71 @@ TEST(SDFParser, FixedJointReductionSimple)
   }
 
   std::map<std::string, double> linkMasses;
-  std::map<std::string, sdf::Pose> linkPoses;
-  std::map<std::string, sdf::Vector3> mapIxxIyyIzz;
-  std::map<std::string, sdf::Vector3> mapIxyIxzIyz;
+  std::map<std::string, ignition::math::Pose3d> linkPoses;
+  std::map<std::string, ignition::math::Vector3d> mapIxxIyyIzz;
+  std::map<std::string, ignition::math::Vector3d> mapIxyIxzIyz;
 
-  const sdf::Vector3 defaultIxxIyyIzz(7, 9, 11);
+  const ignition::math::Vector3d defaultIxxIyyIzz(7, 9, 11);
   {
     std::string linkName = "link1";
     linkMasses[linkName] = 300;
-    linkPoses[linkName] = sdf::Pose();
+    linkPoses[linkName] = ignition::math::Pose3d();
     mapIxxIyyIzz[linkName] = defaultIxxIyyIzz;
-    mapIxyIxzIyz[linkName] = sdf::Vector3();
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d();
   }
 
   {
     std::string linkName = "link1a";
     linkMasses[linkName] = 300;
-    linkPoses[linkName] = sdf::Pose();
+    linkPoses[linkName] = ignition::math::Pose3d();
     mapIxxIyyIzz[linkName] = defaultIxxIyyIzz;
-    mapIxyIxzIyz[linkName] = sdf::Vector3();
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d();
   }
 
   {
     std::string linkName = "link1b";
     linkMasses[linkName] = 300;
-    linkPoses[linkName] = sdf::Pose();
+    linkPoses[linkName] = ignition::math::Pose3d();
     mapIxxIyyIzz[linkName] = defaultIxxIyyIzz;
-    mapIxyIxzIyz[linkName] = sdf::Vector3();
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d();
   }
 
   {
     std::string linkName = "link1c";
     linkMasses[linkName] = 300;
-    linkPoses[linkName] = sdf::Pose(0.2, 0, 0, 0, 0, 0);
-    mapIxxIyyIzz[linkName] = defaultIxxIyyIzz + sdf::Vector3(0, 6, 6);
-    mapIxyIxzIyz[linkName] = sdf::Vector3();
+    linkPoses[linkName] = ignition::math::Pose3d(0.2, 0, 0, 0, 0, 0);
+    mapIxxIyyIzz[linkName] =
+      defaultIxxIyyIzz + ignition::math::Vector3d(0, 6, 6);
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d();
   }
 
   {
     std::string linkName = "link1d";
     linkMasses[linkName] = 300;
-    linkPoses[linkName] = sdf::Pose(0.2, 0, 0, 0, 0, 0);
-    mapIxxIyyIzz[linkName] = defaultIxxIyyIzz + sdf::Vector3(0, 6, 6);
-    mapIxyIxzIyz[linkName] = sdf::Vector3();
+    linkPoses[linkName] = ignition::math::Pose3d(0.2, 0, 0, 0, 0, 0);
+    mapIxxIyyIzz[linkName] =
+      defaultIxxIyyIzz + ignition::math::Vector3d(0, 6, 6);
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d();
   }
 
   {
     std::string linkName = "link1e";
     linkMasses[linkName] = 300;
-    linkPoses[linkName] = sdf::Pose(0.2, 0, 0, 0, 0, 0);
-    mapIxxIyyIzz[linkName] = defaultIxxIyyIzz + sdf::Vector3(0, 6, 6);
-    mapIxyIxzIyz[linkName] = sdf::Vector3();
+    linkPoses[linkName] = ignition::math::Pose3d(0.2, 0, 0, 0, 0, 0);
+    mapIxxIyyIzz[linkName] =
+      defaultIxxIyyIzz + ignition::math::Vector3d(0, 6, 6);
+    mapIxyIxzIyz[linkName] = ignition::math::Vector3d();
   }
 
-  sdf::ElementPtr model = robot->root->GetElement("model");
+  sdf::ElementPtr model = robot->Root()->GetElement("model");
   for (sdf::ElementPtr link = model->GetElement("link"); link;
        link = link->GetNextElement("link"))
   {
     std::string linkName = link->Get<std::string>("name");
     sdf::ElementPtr inertial = link->GetElement("inertial");
     double linkMass = inertial->Get<double>("mass");
-    sdf::Pose linkPose = inertial->Get<sdf::Pose>("pose");
+    ignition::math::Pose3d linkPose =
+      inertial->Get<ignition::math::Pose3d>("pose");
     sdf::ElementPtr inertia = inertial->GetElement("inertia");
     double ixx = inertia->Get<double>("ixx");
     double iyy = inertia->Get<double>("iyy");
@@ -307,11 +316,11 @@ TEST(SDFParser, FixedJointReductionSimple)
 
     EXPECT_NEAR(linkMass, linkMasses[linkName], gc_tolerance);
     EXPECT_EQ(linkPose, linkPoses[linkName]);
-    EXPECT_NEAR(ixx, mapIxxIyyIzz[linkName].x, gc_tolerance);
-    EXPECT_NEAR(iyy, mapIxxIyyIzz[linkName].y, gc_tolerance);
-    EXPECT_NEAR(izz, mapIxxIyyIzz[linkName].z, gc_tolerance);
-    EXPECT_NEAR(ixy, mapIxyIxzIyz[linkName].x, gc_tolerance);
-    EXPECT_NEAR(ixz, mapIxyIxzIyz[linkName].y, gc_tolerance);
-    EXPECT_NEAR(iyz, mapIxyIxzIyz[linkName].z, gc_tolerance);
+    EXPECT_NEAR(ixx, mapIxxIyyIzz[linkName].X(), gc_tolerance);
+    EXPECT_NEAR(iyy, mapIxxIyyIzz[linkName].Y(), gc_tolerance);
+    EXPECT_NEAR(izz, mapIxxIyyIzz[linkName].Z(), gc_tolerance);
+    EXPECT_NEAR(ixy, mapIxyIxzIyz[linkName].X(), gc_tolerance);
+    EXPECT_NEAR(ixz, mapIxyIxzIyz[linkName].Y(), gc_tolerance);
+    EXPECT_NEAR(iyz, mapIxyIxzIyz[linkName].Z(), gc_tolerance);
   }
 }
